Documentation
¶
Index ¶
Constants ¶
const ( // AnalyzeRequestInputTypeCSV for when the user uploaded a CSV file AnalyzeRequestInputTypeCSV = "csv" // AnalyzeRequestInputTypeCredentials type when user submits username and password AnalyzeRequestInputTypeCredentials = "username/password" )
const ( // AnalyzeRequestStatusInProgress indicates that the request is in progress AnalyzeRequestStatusInProgress = AnalyzeRequestStatus("in-progress") )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnalyzeRequest ¶
type AnalyzeRequest struct {
ID id.ID
UserID id.ID
InputType string
OvChipkaartNumber string
Status AnalyzeRequestStatus
StartDate time.Time
EndDate time.Time
CreatedAt time.Time
UpdatedAt time.Time
}
AnalyzeRequest entity
type AnalyzeRequestStatus ¶
type AnalyzeRequestStatus string
AnalyzeRequestStatus is the status of the request
func (AnalyzeRequestStatus) String ¶
func (status AnalyzeRequestStatus) String() string
String converts form status to string
Click to show internal directories.
Click to hide internal directories.