Documentation
¶
Index ¶
- Variables
- func RegisterTransactionsServiceServer(s *grpc.Server, srv TransactionsServiceServer)
- type FetchByCredentialsRequest
- func (*FetchByCredentialsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *FetchByCredentialsRequest) GetCardNumber() string
- func (x *FetchByCredentialsRequest) GetEndDate() *timestamp.Timestamp
- func (x *FetchByCredentialsRequest) GetPassword() string
- func (x *FetchByCredentialsRequest) GetStartDate() *timestamp.Timestamp
- func (x *FetchByCredentialsRequest) GetUsername() string
- func (*FetchByCredentialsRequest) ProtoMessage()
- func (x *FetchByCredentialsRequest) ProtoReflect() protoreflect.Message
- func (x *FetchByCredentialsRequest) Reset()
- func (x *FetchByCredentialsRequest) String() string
- type FetchFromBytesRequest
- func (*FetchFromBytesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *FetchFromBytesRequest) GetCardNumber() string
- func (x *FetchFromBytesRequest) GetData() []byte
- func (x *FetchFromBytesRequest) GetEndDate() *timestamp.Timestamp
- func (x *FetchFromBytesRequest) GetStartDate() *timestamp.Timestamp
- func (*FetchFromBytesRequest) ProtoMessage()
- func (x *FetchFromBytesRequest) ProtoReflect() protoreflect.Message
- func (x *FetchFromBytesRequest) Reset()
- func (x *FetchFromBytesRequest) String() string
- type Transaction
- func (*Transaction) Descriptor() ([]byte, []int)deprecated
- func (x *Transaction) GetCheckInInfo() string
- func (x *Transaction) GetCheckInText() string
- func (x *Transaction) GetEPurseMut() *wrappers.DoubleValue
- func (x *Transaction) GetEPurseMutInfo() string
- func (x *Transaction) GetFare() *wrappers.DoubleValue
- func (x *Transaction) GetFareCalculation() string
- func (x *Transaction) GetFareText() string
- func (x *Transaction) GetModalType() string
- func (x *Transaction) GetProductInfo() string
- func (x *Transaction) GetProductText() string
- func (x *Transaction) GetPto() string
- func (x *Transaction) GetTransactionDateTime() *timestamp.Timestamp
- func (x *Transaction) GetTransactionExplanation() string
- func (x *Transaction) GetTransactionInfo() string
- func (x *Transaction) GetTransactionName() string
- func (x *Transaction) GetTransactionPriority() string
- func (*Transaction) ProtoMessage()
- func (x *Transaction) ProtoReflect() protoreflect.Message
- func (x *Transaction) Reset()
- func (x *Transaction) String() string
- type TransactionsResponse
- func (*TransactionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *TransactionsResponse) GetTransactions() []*Transaction
- func (*TransactionsResponse) ProtoMessage()
- func (x *TransactionsResponse) ProtoReflect() protoreflect.Message
- func (x *TransactionsResponse) Reset()
- func (x *TransactionsResponse) String() string
- type TransactionsServiceClient
- type TransactionsServiceServer
- type UnimplementedTransactionsServiceServer
- type UnsafeTransactionsServiceServer
Constants ¶
This section is empty.
Variables ¶
var File_transactions_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterTransactionsServiceServer ¶
func RegisterTransactionsServiceServer(s *grpc.Server, srv TransactionsServiceServer)
Types ¶
type FetchByCredentialsRequest ¶
type FetchByCredentialsRequest struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
CardNumber string `protobuf:"bytes,3,opt,name=cardNumber,proto3" json:"cardNumber,omitempty"`
StartDate *timestamp.Timestamp `protobuf:"bytes,4,opt,name=startDate,proto3" json:"startDate,omitempty"`
EndDate *timestamp.Timestamp `protobuf:"bytes,5,opt,name=endDate,proto3" json:"endDate,omitempty"`
// contains filtered or unexported fields
}
func (*FetchByCredentialsRequest) Descriptor
deprecated
func (*FetchByCredentialsRequest) Descriptor() ([]byte, []int)
Deprecated: Use FetchByCredentialsRequest.ProtoReflect.Descriptor instead.
func (*FetchByCredentialsRequest) GetCardNumber ¶
func (x *FetchByCredentialsRequest) GetCardNumber() string
func (*FetchByCredentialsRequest) GetEndDate ¶
func (x *FetchByCredentialsRequest) GetEndDate() *timestamp.Timestamp
func (*FetchByCredentialsRequest) GetPassword ¶
func (x *FetchByCredentialsRequest) GetPassword() string
func (*FetchByCredentialsRequest) GetStartDate ¶
func (x *FetchByCredentialsRequest) GetStartDate() *timestamp.Timestamp
func (*FetchByCredentialsRequest) GetUsername ¶
func (x *FetchByCredentialsRequest) GetUsername() string
func (*FetchByCredentialsRequest) ProtoMessage ¶
func (*FetchByCredentialsRequest) ProtoMessage()
func (*FetchByCredentialsRequest) ProtoReflect ¶
func (x *FetchByCredentialsRequest) ProtoReflect() protoreflect.Message
func (*FetchByCredentialsRequest) Reset ¶
func (x *FetchByCredentialsRequest) Reset()
func (*FetchByCredentialsRequest) String ¶
func (x *FetchByCredentialsRequest) String() string
type FetchFromBytesRequest ¶
type FetchFromBytesRequest struct {
CardNumber string `protobuf:"bytes,1,opt,name=cardNumber,proto3" json:"cardNumber,omitempty"`
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
StartDate *timestamp.Timestamp `protobuf:"bytes,3,opt,name=startDate,proto3" json:"startDate,omitempty"`
EndDate *timestamp.Timestamp `protobuf:"bytes,4,opt,name=endDate,proto3" json:"endDate,omitempty"`
// contains filtered or unexported fields
}
func (*FetchFromBytesRequest) Descriptor
deprecated
func (*FetchFromBytesRequest) Descriptor() ([]byte, []int)
Deprecated: Use FetchFromBytesRequest.ProtoReflect.Descriptor instead.
func (*FetchFromBytesRequest) GetCardNumber ¶
func (x *FetchFromBytesRequest) GetCardNumber() string
func (*FetchFromBytesRequest) GetData ¶
func (x *FetchFromBytesRequest) GetData() []byte
func (*FetchFromBytesRequest) GetEndDate ¶
func (x *FetchFromBytesRequest) GetEndDate() *timestamp.Timestamp
func (*FetchFromBytesRequest) GetStartDate ¶
func (x *FetchFromBytesRequest) GetStartDate() *timestamp.Timestamp
func (*FetchFromBytesRequest) ProtoMessage ¶
func (*FetchFromBytesRequest) ProtoMessage()
func (*FetchFromBytesRequest) ProtoReflect ¶
func (x *FetchFromBytesRequest) ProtoReflect() protoreflect.Message
func (*FetchFromBytesRequest) Reset ¶
func (x *FetchFromBytesRequest) Reset()
func (*FetchFromBytesRequest) String ¶
func (x *FetchFromBytesRequest) String() string
type Transaction ¶
type Transaction struct {
CheckInInfo string `protobuf:"bytes,1,opt,name=checkInInfo,proto3" json:"checkInInfo,omitempty"`
CheckInText string `protobuf:"bytes,2,opt,name=checkInText,proto3" json:"checkInText,omitempty"`
Fare *wrappers.DoubleValue `protobuf:"bytes,3,opt,name=fare,proto3" json:"fare,omitempty"`
FareCalculation string `protobuf:"bytes,4,opt,name=fareCalculation,proto3" json:"fareCalculation,omitempty"`
FareText string `protobuf:"bytes,5,opt,name=fareText,proto3" json:"fareText,omitempty"`
ModalType string `protobuf:"bytes,6,opt,name=modalType,proto3" json:"modalType,omitempty"`
ProductInfo string `protobuf:"bytes,7,opt,name=productInfo,proto3" json:"productInfo,omitempty"`
ProductText string `protobuf:"bytes,8,opt,name=productText,proto3" json:"productText,omitempty"`
Pto string `protobuf:"bytes,9,opt,name=pto,proto3" json:"pto,omitempty"`
TransactionDateTime *timestamp.Timestamp `protobuf:"bytes,10,opt,name=transactionDateTime,proto3" json:"transactionDateTime,omitempty"`
TransactionInfo string `protobuf:"bytes,11,opt,name=transactionInfo,proto3" json:"transactionInfo,omitempty"`
TransactionName string `protobuf:"bytes,12,opt,name=transactionName,proto3" json:"transactionName,omitempty"`
EPurseMut *wrappers.DoubleValue `protobuf:"bytes,13,opt,name=ePurseMut,proto3" json:"ePurseMut,omitempty"`
EPurseMutInfo string `protobuf:"bytes,14,opt,name=ePurseMutInfo,proto3" json:"ePurseMutInfo,omitempty"`
TransactionExplanation string `protobuf:"bytes,15,opt,name=transactionExplanation,proto3" json:"transactionExplanation,omitempty"`
TransactionPriority string `protobuf:"bytes,16,opt,name=transactionPriority,proto3" json:"transactionPriority,omitempty"`
// contains filtered or unexported fields
}
func (*Transaction) Descriptor
deprecated
func (*Transaction) Descriptor() ([]byte, []int)
Deprecated: Use Transaction.ProtoReflect.Descriptor instead.
func (*Transaction) GetCheckInInfo ¶
func (x *Transaction) GetCheckInInfo() string
func (*Transaction) GetCheckInText ¶
func (x *Transaction) GetCheckInText() string
func (*Transaction) GetEPurseMut ¶
func (x *Transaction) GetEPurseMut() *wrappers.DoubleValue
func (*Transaction) GetEPurseMutInfo ¶
func (x *Transaction) GetEPurseMutInfo() string
func (*Transaction) GetFare ¶
func (x *Transaction) GetFare() *wrappers.DoubleValue
func (*Transaction) GetFareCalculation ¶
func (x *Transaction) GetFareCalculation() string
func (*Transaction) GetFareText ¶
func (x *Transaction) GetFareText() string
func (*Transaction) GetModalType ¶
func (x *Transaction) GetModalType() string
func (*Transaction) GetProductInfo ¶
func (x *Transaction) GetProductInfo() string
func (*Transaction) GetProductText ¶
func (x *Transaction) GetProductText() string
func (*Transaction) GetPto ¶
func (x *Transaction) GetPto() string
func (*Transaction) GetTransactionDateTime ¶
func (x *Transaction) GetTransactionDateTime() *timestamp.Timestamp
func (*Transaction) GetTransactionExplanation ¶
func (x *Transaction) GetTransactionExplanation() string
func (*Transaction) GetTransactionInfo ¶
func (x *Transaction) GetTransactionInfo() string
func (*Transaction) GetTransactionName ¶
func (x *Transaction) GetTransactionName() string
func (*Transaction) GetTransactionPriority ¶
func (x *Transaction) GetTransactionPriority() string
func (*Transaction) ProtoMessage ¶
func (*Transaction) ProtoMessage()
func (*Transaction) ProtoReflect ¶
func (x *Transaction) ProtoReflect() protoreflect.Message
func (*Transaction) Reset ¶
func (x *Transaction) Reset()
func (*Transaction) String ¶
func (x *Transaction) String() string
type TransactionsResponse ¶
type TransactionsResponse struct {
Transactions []*Transaction `protobuf:"bytes,1,rep,name=transactions,proto3" json:"transactions,omitempty"`
// contains filtered or unexported fields
}
func (*TransactionsResponse) Descriptor
deprecated
func (*TransactionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use TransactionsResponse.ProtoReflect.Descriptor instead.
func (*TransactionsResponse) GetTransactions ¶
func (x *TransactionsResponse) GetTransactions() []*Transaction
func (*TransactionsResponse) ProtoMessage ¶
func (*TransactionsResponse) ProtoMessage()
func (*TransactionsResponse) ProtoReflect ¶
func (x *TransactionsResponse) ProtoReflect() protoreflect.Message
func (*TransactionsResponse) Reset ¶
func (x *TransactionsResponse) Reset()
func (*TransactionsResponse) String ¶
func (x *TransactionsResponse) String() string
type TransactionsServiceClient ¶
type TransactionsServiceClient interface {
FetchByCredentials(ctx context.Context, in *FetchByCredentialsRequest, opts ...grpc.CallOption) (*TransactionsResponse, error)
FetchFromBytes(ctx context.Context, in *FetchFromBytesRequest, opts ...grpc.CallOption) (*TransactionsResponse, error)
}
TransactionsServiceClient is the client API for TransactionsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTransactionsServiceClient ¶
func NewTransactionsServiceClient(cc grpc.ClientConnInterface) TransactionsServiceClient
type TransactionsServiceServer ¶
type TransactionsServiceServer interface {
FetchByCredentials(context.Context, *FetchByCredentialsRequest) (*TransactionsResponse, error)
FetchFromBytes(context.Context, *FetchFromBytesRequest) (*TransactionsResponse, error)
// contains filtered or unexported methods
}
TransactionsServiceServer is the server API for TransactionsService service. All implementations must embed UnimplementedTransactionsServiceServer for forward compatibility
type UnimplementedTransactionsServiceServer ¶
type UnimplementedTransactionsServiceServer struct {
}
UnimplementedTransactionsServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedTransactionsServiceServer) FetchByCredentials ¶
func (UnimplementedTransactionsServiceServer) FetchByCredentials(context.Context, *FetchByCredentialsRequest) (*TransactionsResponse, error)
func (UnimplementedTransactionsServiceServer) FetchFromBytes ¶
func (UnimplementedTransactionsServiceServer) FetchFromBytes(context.Context, *FetchFromBytesRequest) (*TransactionsResponse, error)
type UnsafeTransactionsServiceServer ¶
type UnsafeTransactionsServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTransactionsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TransactionsServiceServer will result in compilation errors.